@@ -5,8 +5,7 @@
 /*  The code for generating a calendar.                        */
 /*                                                             */
 /*  This file is part of REMIND.                               */
-/*  Copyright (C) 1992-1998 by Dianne Skoll                    */
-/*  Copyright (C) 1999-2000 by Roaring Penguin Software Inc.   */
+/*  Copyright (C) 1992-2018 by Dianne Skoll                    */
 /*                                                             */
 /***************************************************************/
 
@@ -277,7 +276,7 @@ void ProduceCalendar(void)
 /*  Write a calendar for a single week                         */
 /*                                                             */
 /***************************************************************/
-static void DoCalendarOneWeek(nleft)
+static void DoCalendarOneWeek(int nleft)
 {
     int y, m, d, done, i, l, wd;
     char buf[81];
